@@ -7,9 +7,15 @@ use File::Basename 'dirname';
 use lib catdir(dirname(__FILE__), '../lib');
 use lib catdir(dirname(__FILE__), '/lib');
 
-app->routes->namespace('RouteTest');
+plugin 'AutoRoute';
 
-plugin 'AutoRoute', {ignore => [qw/layouts include/]};
+  use Mojo::Cache;
+  app->hook(before_dispatch => sub {
+    my $c = shift;
+    
+    # Clear cache
+    $c->app->renderer->cache(Mojo::Cache->new);
+  });
 
 app->start;
 
